<template>
    <div class="notice">
        <el-dialog
            v-model="dialogVisible"
            :title="title"
            width="500px"
            :before-close="handleClose"
        >
            <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="110px" >
              <el-form-item label="类型:" prop="label">
                <el-radio-group v-model="state.form.scoreType">
                  <el-radio label="1" size="large" border>加分项</el-radio>
                  <el-radio label="2" size="large" border>扣分项</el-radio>
                </el-radio-group>
              </el-form-item>
              <el-form-item label="标准分值:" prop="score">
                  <el-input v-model.trim="state.form.score"></el-input>
              </el-form-item>
              <el-form-item label="内容:" prop="content">
                <el-input v-model.trim="state.form.content" type="textarea" :autosize="{minRows: 2}"></el-input>
              </el-form-item>
            </el-form>
            <template #footer>
                    <span class="dialog-footer">
                        <el-button @click="handleClose" size="default">取 消</el-button>
                        <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
                    </span>
            </template>
        </el-dialog>
    </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import Editor from "@/components/Editor/index.vue";
import {ElMessage} from "element-plus";
import {addNotice} from "@/api/backManage/notice";
import {addDict, addReview, editDict, editReview, getDictDetail} from "@/api/backManage/evaluate";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const state = reactive({
    form: {
      id: '',
      score: '',
      content: '',
      scoreType: null
    },
    formRules:{
      scoreType: [{ required: true, message: '请选择类型', trigger: 'blur' }],
      score: [{ required: true, message: '请输入标准分值', trigger: 'blur' }],
      content: [{ required: true, message: '请输入内容', trigger: 'blur' }]
    },

})

const openDialog = async (type, value) => {
    title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看';
    if(type === 'edit') {
        state.form = value
    }
    dialogVisible.value = true
}

const onSubmit = async () => {
    const valid = await busRef.value.validate();
    if(valid){
        if(title.value === '新增'){
            const param = {
              score: state.form.score,
              content: state.form.content,
              scoreType: state.form.scoreType
            }
            const res = await addReview(param)
            if(res.code === 200){
                ElMessage({
                    type: 'success',
                    message: '新增成功'
                });
            }else{
                ElMessage.warning(res.message)
            }
            emit("getList")
            busRef.value.clearValidate();
            dialogVisible.value = false;
        }else if(title.value === '编辑'){
            const param = {
              id: state.form.id,
              score: state.form.score,
              content: state.form.content,
              scoreType: state.form.scoreType
            }
            const res = await editReview(param)
            if(res.code === 200){
                ElMessage({
                    type: 'success',
                    message: '修改成功'
                });
            }else{
                ElMessage.warning(res.message)
            }
            emit("getList")
            busRef.value.clearValidate();
            dialogVisible.value = false;
        }
    }
}

const handleClose = () => {
    busRef.value.clearValidate();
    reset();
    dialogVisible.value = false;

}
const reset = () => {
    state.form = {
      id: '',
      score: '',
      content: '',
      scoreType: null
    }
}
defineExpose({
    openDialog
});

</script>

<style scoped lang="scss">
.notice{
    :deep(.el-form .el-form-item__label) {
        font-size: 15px;
    }
    .file {
        display: flex;
        flex-direction: column;
        align-items: flex-start;
    }
}
</style>
